% Auto-generated chapter 11 for tirmidhi
% Hadiths in this chapter: 67

\hadithdefcmd{tirmidhi}{1080}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الْحَجَّاجِ، عَنْ مَكْحُولٍ، عَنْ أَبِي الشِّمَالِ، عَنْ أَبِي أَيُّوبَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْبَعٌ مِنْ سُنَنِ الْمُرْسَلِينَ الْحَيَاءُ وَالتَّعَطُّرُ وَالسِّوَاكُ وَالنِّكَاحُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُثْمَانَ وَثَوْبَانَ وَابْنِ مَسْعُودٍ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي نَجِيحٍ وَجَابِرٍ وَعَكَّافٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي أَيُّوبَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ حَدَّثَنَا مَحْمُودُ بْنُ خِدَاشٍ الْبَغْدَادِيُّ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنِ الْحَجَّاجِ، عَنْ مَكْحُولٍ، عَنْ أَبِي الشِّمَالِ، عَنْ أَبِي أَيُّوبَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ حَفْصٍ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى هَذَا الْحَدِيثَ هُشَيْمٌ وَمُحَمَّدُ بْنُ يَزِيدَ الْوَاسِطِيُّ وَأَبُو مُعَاوِيَةَ وَغَيْرُ وَاحِدٍ عَنِ الْحَجَّاجِ عَنْ مَكْحُولٍ عَنْ أَبِي أَيُّوبَ وَلَمْ يَذْكُرُوا فِيهِ عَنْ أَبِي الشِّمَالِ وَحَدِيثُ حَفْصِ بْنِ غِيَاثٍ وَعَبَّادِ بْنِ الْعَوَّامِ أَصَحُّ ‏.‏\hadithno{1080}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Ayyub narrated that :The Messenger of Allah said: "Four are from the Sunan of the Messengers: Al-Hayat, using Atar, the Siwak, and marriage}}
\hadithdefcmd{tirmidhi}{1081}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم وَنَحْنُ شَبَابٌ لاَ نَقْدِرُ عَلَى شَيْءٍ فَقَالَ ‏ "‏ يَا مَعْشَرَ الشَّبَابِ عَلَيْكُمْ بِالْبَاءَةِ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ فَمَنْ لَمْ يَسْتَطِعْ مِنْكُمُ الْبَاءَةَ فَعَلَيْهِ بِالصَّوْمِ فَإِنَّ الصَّوْمَ لَهُ وِجَاءٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ عُمَارَةَ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى غَيْرُ، وَاحِدٍ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَ هَذَا ‏.‏ وَرَوَى أَبُو مُعَاوِيَةَ، وَالْمُحَارِبِيُّ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى كِلاَهُمَا صَحِيحٌ ‏.‏\hadithno{1081}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Mas'ud narrated:"We went with Allah's Messenger, while we were young men who had nothing. He said: 'O young men! You should marry, for indeed it helps in lowering the gaze and protecting the private parts. Whoever among you is not able to marry, then let him fast, for indeed fasting will diminish his sexual desire}}
\hadithdefcmd{tirmidhi}{1082}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، وَزَيْدُ بْنُ أَخْزَمَ الطَّائِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ الْبَصْرِيُّ، قَالُوا حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، عَنْ أَبِيهِ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ التَّبَتُّلِ ‏.‏ قَالَ أَبُو عِيسَى وَزَادَ زَيْدُ بْنُ أَخْزَمَ فِي حَدِيثِهِ وَقَرَأَ قَتَادَةُ ‏:‏ ‏(‏ولقدْ أَرْسَلْنا رُسُلاً مِنْ قَبْلِكَ وَجَعَلْنَا لَهُمْ أَزْوَاجًا وَذُرِّيَّةً ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدٍ وَأَنَسِ بْنِ مَالِكٍ وَعَائِشَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَمُرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى الأَشْعَثُ بْنُ عَبْدِ الْمَلِكِ هَذَا الْحَدِيثَ عَنِ الْحَسَنِ عَنْ سَعْدِ بْنِ هِشَامٍ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَيُقَالُ كِلاَ الْحَدِيثَيْنِ صَحِيحٌ ‏.‏\hadithno{1082}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Qatadah narrated from Al-Hasan, from Samurah that:The Prophet prohibited celibacy}}
\hadithdefcmd{tirmidhi}{1083}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَغَيْرُ، وَاحِدٍ، قَالُوا أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ رَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى عُثْمَانَ بْنِ مَظْعُونٍ التَّبَتُّلَ وَلَوْ أَذِنَ لَهُ لاَخْتَصَيْنَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1083}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'eed bin Al-Musayyab narrated from Sa'b bin Abi Waqqas:"The Messenger of Allah refused Uthman bin Ma'zun (when he asked) regarding celibacy, and if he had permitted it for him, then we would have castrated ourselves}}
\hadithdefcmd{tirmidhi}{1084}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ سُلَيْمَانَ، عَنِ ابْنِ عَجْلاَنَ، عَنِ ابْنِ وَثِيمَةَ النَّصْرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا خَطَبَ إِلَيْكُمْ مَنْ تَرْضَوْنَ دِينَهُ وَخُلُقَهُ فَزَوِّجُوهُ إِلاَّ تَفْعَلُوا تَكُنْ فِتْنَةٌ فِي الأَرْضِ وَفَسَادٌ عَرِيضٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي حَاتِمٍ الْمُزَنِيِّ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ قَدْ خُولِفَ عَبْدُ الْحَمِيدِ بْنُ سُلَيْمَانَ فِي هَذَا الْحَدِيثِ ‏.‏ فَرَوَاهُ اللَّيْثُ بْنُ سَعْدٍ عَنِ ابْنِ عَجْلاَنَ عَنْ عَبْدِ اللَّهِ بْنِ هُرْمُزَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ قَالَ أَبُو عِيسَى قَالَ مُحَمَّدٌ وَحَدِيثُ اللَّيْثِ أَشْبَهُ ‏.‏ وَلَمْ يَعُدَّ حَدِيثَ عَبْدِ الْحَمِيدِ مَحْفُوظًا ‏.‏\hadithno{1084}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "When someone whose religion and character you are pleased with proposes to (someone under the care) of one of you, then marry to him. If you do not do so, then there will be turmoil (Fitnah) in the land and abounding discord (Fasad)}}
\hadithdefcmd{tirmidhi}{1085}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو السَّوَّاقُ الْبَلْخِيُّ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمِ بْنِ هُرْمُزَ، عَنْ مُحَمَّدٍ، وَسَعِيدٍ، ابْنَىْ عُبَيْدٍ عَنْ أَبِي حَاتِمٍ الْمُزَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا جَاءَكُمْ مَنْ تَرْضَوْنَ دِينَهُ وَخُلُقَهُ فَأَنْكِحُوهُ إِلاَّ تَفْعَلُوا تَكُنْ فِتْنَةٌ فِي الأَرْضِ وَفَسَادٌ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَإِنْ كَانَ فِيهِ قَالَ ‏"‏ إِذَا جَاءَكُمْ مَنْ تَرْضَوْنَ دِينَهُ وَخُلُقَهُ فَأَنْكِحُوهُ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو حَاتِمٍ الْمُزَنِيُّ لَهُ صُحْبَةٌ وَلاَ نَعْرِفُ لَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ هَذَا الْحَدِيثِ ‏.‏\hadithno{1085}\hadithgrade{Ahmad Muhammad Shakir: Hasan Lighairihi; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hatim Al-Muzani narrated that:The Messenger of Allah said: "When someone whose religion and character you are pleased with comes to you then marry (her to) him. If you do not do so, then there will be turmoil (Fitnah) in the land and discord (Fasad). If you do not do so, then there will be turmoil (Fitnah) in the land and discord (Fasad)." They said: "O Messenger of Allah! What if there was something about him?" He said: "When someone whose religion and character you are pleased with comes to you then marry him." (And he (pbuh) said this) three times}}
\hadithdefcmd{tirmidhi}{1086}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى، أَخْبَرَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَرْأَةَ تُنْكَحُ عَلَى دِينِهَا وَمَالِهَا وَجَمَالِهَا فَعَلَيْكَ بِذَاتِ الدِّينِ تَرِبَتْ يَدَاكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَوْفِ بْنِ مَالِكٍ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1086}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir narrated that:The Prophet said: "Indeed the woman is married for her religion, her wealth, and her beauty, so take the one with religion, and may your hands be dusty}}
\hadithdefcmd{tirmidhi}{1087}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، قَالَ حَدَّثَنِي عَاصِمُ بْنُ سُلَيْمَانَ، هُوَ الأَحْوَلُ عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّهُ خَطَبَ امْرَأَةً فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ انْظُرْ إِلَيْهَا فَإِنَّهُ أَحْرَى أَنْ يُؤْدَمَ بَيْنَكُمَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ مُحَمَّدِ بْنِ مَسْلَمَةَ وَجَابِرٍ وَأَنَسٍ وَأَبِي حُمَيْدٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا الْحَدِيثِ وَقَالُوا لاَ بَأْسَ أَنْ يَنْظُرَ إِلَيْهَا مَا لَمْ يَرَ مِنْهَا مُحَرَّمًا ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ أَحْرَى أَنْ يُؤْدَمَ بَيْنَكُمَا ‏"‏ قَالَ أَحْرَى أَنْ تَدُومَ الْمَوَدَّةُ بَيْنَكُمَا ‏.‏\hadithno{1087}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Bakr bin Abdullah Al-Muzani narrated that :Al-Mughirah bin Shu'bah proposed to a woman, so the Prophet said: "Look at her, for indeed that is more likely to make things better between the two of you}}
\hadithdefcmd{tirmidhi}{1088}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بَلْجٍ، عَنْ مُحَمَّدِ بْنِ حَاطِبٍ الْجُمَحِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَصْلُ مَا بَيْنَ الْحَرَامِ وَالْحَلاَلِ الدُّفُّ وَالصَّوْتُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَجَابِرٍ وَالرُّبَيِّعِ بِنْتِ مُعَوِّذٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مُحَمَّدِ بْنِ حَاطِبٍ حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو بَلْجٍ اسْمُهُ يَحْيَى بْنُ أَبِي سُلَيْمٍ وَيُقَالُ ابْنُ سُلَيْمٍ أَيْضًا ‏.‏ وَمُحَمَّدُ بْنُ حَاطِبٍ قَدْ رَأَى النَّبِيَّ صلى الله عليه وسلم وَهُوَ غُلاَمٌ صَغِيرٌ ‏.‏\hadithno{1088}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Al-Balj narrated from Muhammad bin Hatib Al-Jumahi who said that:The Messenger of Allah said: "The distinction between the lawful and the unlawful is the Duff and the voice}}
\hadithdefcmd{tirmidhi}{1089}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا عِيسَى بْنُ مَيْمُونٍ الأَنْصَارِيُّ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعْلِنُوا هَذَا النِّكَاحَ وَاجْعَلُوهُ فِي الْمَسَاجِدِ وَاضْرِبُوا عَلَيْهِ بِالدُّفُوفِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ حَسَنٌ فِي هَذَا الْبَابِ ‏.‏ وَعِيسَى بْنُ مَيْمُونٍ الأَنْصَارِيُّ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏ وَعِيسَى بْنُ مَيْمُونٍ الَّذِي يَرْوِي عَنِ ابْنِ أَبِي نَجِيحٍ التَّفْسِيرَ هُوَ ثِقَةٌ ‏.‏\hadithno{1089}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated that:The Messenger of Allah said: "Publicize this marriage, and hold it in the Masjid, and beat the Duff for it}}
\hadithdefcmd{tirmidhi}{1090}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ الْبَصْرِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا خَالِدُ بْنُ ذَكْوَانَ، عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذٍ، قَالَتْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَخَلَ عَلَىَّ غَدَاةَ بُنِيَ بِي فَجَلَسَ عَلَى فِرَاشِي كَمَجْلِسِكَ مِنِّي وَجُوَيْرِيَاتٌ لَنَا يَضْرِبْنَ بِدُفُوفِهِنَّ وَيَنْدُبْنَ مَنْ قُتِلَ مِنْ آبَائِي يَوْمَ بَدْرٍ إِلَى أَنْ قَالَتْ إِحْدَاهُنَّ وَفِينَا نَبِيٌّ يَعْلَمُ مَا فِي غَدٍ ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْكُتِي عَنْ هَذِهِ وَقُولِي الَّذِي كُنْتِ تَقُولِينَ قَبْلَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1090}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ar-Rubai bint Muawwidh said:"The morning after the consummation of my marriage, the Prophet came and sat on my bed as far from me as you are sitting now, and our little girls started beating the Duff and reciting verses mourning my father who had been killed in the battle of Badr. One of them said: 'Among us is a Prophet who knows what will happen tomorrow.' On that the Prophet said: 'Stop saying this, and keep on saying what you were saying before}}
\hadithdefcmd{tirmidhi}{1091}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا رَفَّأَ الإِنْسَانَ إِذَا تَزَوَّجَ قَالَ ‏ "‏ بَارَكَ اللَّهُ لَكَ وَبَارَكَ عَلَيْكَ وَجَمَعَ بَيْنَكُمَا فِي خَيْرٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَقِيلِ بْنِ أَبِي طَالِبٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1091}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that:When supplicating for the newlywed, the Prophet would say: (Barak Allahu laka wa baraka alaik, wa jama'a bainakuma fi khair.) "May Allah bless you and send blessings upon you, and bring goodness between you}}
\hadithdefcmd{tirmidhi}{1092}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ أَحَدَكُمْ إِذَا أَتَى أَهْلَهُ قَالَ بِسْمِ اللَّهِ اللَّهُمَّ جَنِّبْنَا الشَّيْطَانَ وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنَا فَإِنْ قَضَى اللَّهُ بَيْنَهُمَا وَلَدًا لَمْ يَضُرَّهُ الشَّيْطَانُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1092}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated that:The Messenger of Allah said: "If anyone of you, when having sexual intercourse with his wife, says: (Bismillah, Allahumma jannibnash-Shaitana wa jannibish-Shaitana ma razaqtana) 'In the Name of Allah, O Allah! Protect me from Shaitan and protect what you bestow upon us from Shaitan' - then if Allah decrees that they should have a child, Shaitan will not be able to harm him}}
\hadithdefcmd{tirmidhi}{1093}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي شَوَّالٍ وَبَنَى بِي فِي شَوَّالٍ ‏.‏ وَكَانَتْ عَائِشَةُ تَسْتَحِبُّ أَنْ يُبْنَى بِنِسَائِهَا فِي شَوَّالٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الثَّوْرِيِّ عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ ‏.‏\hadithno{1093}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"The Messenger of Allah married me in Shawwal, and he took up residence with me in Shawwal}}
\hadithdefcmd{tirmidhi}{1094}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى عَلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَثَرَ صُفْرَةٍ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ فَقَالَ إِنِّي تَزَوَّجْتُ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ فَقَالَ ‏"‏ بَارَكَ اللَّهُ لَكَ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَعَائِشَةَ وَجَابِرٍ وَزُهَيْرِ بْنِ عُثْمَانَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَالَ أَحْمَدُ بْنُ حَنْبَلٍ وَزْنُ نَوَاةٍ مِنْ ذَهَبٍ وَزْنُ ثَلاَثَةِ دَرَاهِمَ وَثُلُثٍ ‏.‏ وَقَالَ إِسْحَاقُ هُوَ وَزْنُ خَمْسَةِ دَرَاهِمَ وَثُلُثٍ ‏.‏\hadithno{1094}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:The Messenger of Allah saw some traces of saffron on `Abdur-Rahman bin `Awf so he said: 'What is this?' He said: 'I married a woman for the amount of gold equal to a date stone.' So he said: 'May Allah bless you. Have a banquet, even if with only one sheep}}
\hadithdefcmd{tirmidhi}{1095}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ وَائِلِ بْنِ دَاوُدَ، عَنِ ابْنِهِ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَوْلَمَ عَلَى صَفِيَّةَ بِنْتِ حُيَىٍّ بِسَوِيقٍ وَتَمْرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1095}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik narrated:"The Prophet had a banquet for Safiyyah bint Huyayy with Sawiq and dates}}
\hadithdefcmd{tirmidhi}{1096}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْحُمَيْدِيُّ، عَنْ سُفْيَانَ، نَحْوَ هَذَا ‏.‏ وَقَدْ رَوَى غَيْرُ، وَاحِدٍ، هَذَا الْحَدِيثَ عَنِ ابْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، وَلَمْ يَذْكُرُوا فِيهِ عَنْ وَائِلٍ، عَنِ ابْنِهِ، ‏.‏ قَالَ أَبُو عِيسَى وَكَانَ سُفْيَانُ بْنُ عُيَيْنَةَ يُدَلِّسُ فِي هَذَا الْحَدِيثِ فَرُبَّمَا لَمْ يَذْكُرْ فِيهِ عَنْ وَائِلٍ عَنِ ابْنِهِ وَرُبَّمَا ذَكَرَهُ ‏.‏\hadithno{1096}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{(Another chain similar to the narration as no. 1095) :Others have reported this Hadith from Ibn Uyainah, from Az-Zuhri, from Anas, and they did not mention "from Wa'il, from his son Nawf" in it}}
\hadithdefcmd{tirmidhi}{1097}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْبَصْرِيُّ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ طَعَامُ أَوَّلِ يَوْمٍ حَقٌّ وَطَعَامُ يَوْمِ الثَّانِي سُنَّةٌ وَطَعَامُ يَوْمِ الثَّالِثِ سُمْعَةٌ وَمَنْ سَمَّعَ سَمَّعَ اللَّهُ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ زِيَادِ بْنِ عَبْدِ اللَّهِ ‏.‏ وَزِيَادُ بْنُ عَبْدِ اللَّهِ كَثِيرُ الْغَرَائِبِ وَالْمَنَاكِيرِ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَذْكُرُ عَنْ مُحَمَّدِ بْنِ عُقْبَةَ قَالَ قَالَ وَكِيعٌ زِيَادُ بْنُ عَبْدِ اللَّهِ مَعَ شَرَفِهِ لاَ يَكْذِبُ فِي الْحَدِيثِ ‏.‏\hadithno{1097}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Mas'ud narrated that :The Messenger of Allah said: "Having food on the first day is was is obligatory, and having food on the second day is Sunnah, and having food on the third day is to be heard of, and whoever wants to be heard of, Allah will make him heard of}}
\hadithdefcmd{tirmidhi}{1098}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ائْتُوا الدَّعْوَةَ إِذَا دُعِيتُمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي هُرَيْرَةَ وَالْبَرَاءِ وَأَنَسٍ وَأَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1098}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated that:The Messenger of Allah said: "Accept the invitation when you are offered}}
\hadithdefcmd{tirmidhi}{1099}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ جَاءَ رَجُلٌ يُقَالُ لَهُ أَبُو شُعَيْبٍ إِلَى غُلاَمٍ لَهُ لَحَّامٍ فَقَالَ اصْنَعْ لِي طَعَامًا يَكْفِي خَمْسَةً فَإِنِّي رَأَيْتُ فِي وَجْهِ رَسُولِ اللَّهِ صلى الله عليه وسلم الْجُوعَ ‏.‏ قَالَ فَصَنَعَ طَعَامًا ثُمَّ أَرْسَلَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَدَعَاهُ وَجُلَسَاءَهُ الَّذِينَ مَعَهُ فَلَمَّا قَامَ النَّبِيُّ صلى الله عليه وسلم اتَّبَعَهُمْ رَجُلٌ لَمْ يَكُنْ مَعَهُمْ حِينَ دُعُوا فَلَمَّا انْتَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْبَابِ قَالَ لِصَاحِبِ الْمَنْزِلِ ‏ "‏ إِنَّهُ اتَّبَعَنَا رَجُلٌ لَمْ يَكُنْ مَعَنَا حِينَ دَعَوْتَنَا فَإِنْ أَذِنْتَ لَهُ دَخَلَ ‏"‏ ‏.‏ قَالَ فَقَدْ أَذِنَّا لَهُ فَلْيَدْخُلْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{1099}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Mas'ud narrated:"A man named Abu Shu'aib came to a slave of his, who was a butcher, and said: 'Prepare some food for me that will be sufficient for five, for I have seen hunger in the face of the Messenger of Allah.' So he prepared some food. Then he sent a message to the Prophet inviting him and those who were sitting with him. When the Prophet stood, he was followed by a man who was not with them when they were invited. When the Messenger of Allah arrive at the door he said to the owner of the house: 'A man who was not with us when you invited us followed us, if you permit him, he will enter.'" He said: We have permitted him, let him enter}}
\hadithdefcmd{tirmidhi}{1100}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ تَزَوَّجْتُ امْرَأَةً فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَتَزَوَّجْتَ يَا جَابِرُ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ ‏"‏ بِكْرًا أَمْ ثَيِّبًا ‏"‏ ‏.‏ فَقُلْتُ لاَ بَلْ ثَيِّبًا ‏.‏ فَقَالَ ‏"‏ هَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ عَبْدَ اللَّهِ مَاتَ وَتَرَكَ سَبْعَ بَنَاتٍ أَوْ تِسْعًا فَجِئْتُ بِمَنْ يَقُومُ عَلَيْهِنَّ ‏.‏ قَالَ فَدَعَا لِي ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُبَىِّ بْنِ كَعْبٍ وَكَعْبِ بْنِ عُجْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرِ بْنِ عَبْدِ اللَّهِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1100}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir bin Abdullah narrated:"I married a woman and went to the Prophet, he said: 'O Jabir! Have you married?' I said: 'Yes.' He said: 'A virgin or a matron?' I said: 'A matron.' He said: 'Why didn't you marry a young girl, so that you may play with her and she with you?' I said: 'O Messenger of Allah! Abdullah (his father) died and left behind seven - or nine - daughter, so I have brought someone who can look after them.'" (He said:) "So he supplicated for me}}
\hadithdefcmd{tirmidhi}{1101}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي إِسْحَاقَ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي إِسْحَاقَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَعِمْرَانَ بْنِ حُصَيْنٍ وَأَنَسٍ ‏.‏\hadithno{1101}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Musa narrated that :the Messenger of Allah said: "There is no marriage except with a Wali}}
\hadithdefcmd{tirmidhi}{1102}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَيُّمَا امْرَأَةٍ نُكِحَتْ بِغَيْرِ إِذْنِ وَلِيِّهَا فَنِكَاحُهَا بَاطِلٌ فَنِكَاحُهَا بَاطِلٌ فَنِكَاحُهَا بَاطِلٌ فَإِنْ دَخَلَ بِهَا فَلَهَا الْمَهْرُ بِمَا اسْتَحَلَّ مِنْ فَرْجِهَا فَإِنِ اشْتَجَرُوا فَالسُّلْطَانُ وَلِيُّ مَنْ لاَ وَلِيَّ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ وَيَحْيَى بْنُ أَيُّوبَ وَسُفْيَانُ الثَّوْرِيُّ وَغَيْرُ وَاحِدٍ مِنَ الْحُفَّاظِ عَنِ ابْنِ جُرَيْجٍ نَحْوَ هَذَا ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي مُوسَى حَدِيثٌ فِيهِ اخْتِلاَفٌ رَوَاهُ إِسْرَائِيلُ وَشَرِيكُ بْنُ عَبْدِ اللَّهِ وَأَبُو عَوَانَةَ وَزُهَيْرُ بْنُ مُعَاوِيَةَ وَقَيْسُ بْنُ الرَّبِيعِ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي بُرْدَةَ عَنْ أَبِي مُوسَى عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى أَسْبَاطُ بْنُ مُحَمَّدٍ وَزَيْدُ بْنُ حُبَابٍ عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي بُرْدَةَ عَنْ أَبِي مُوسَى عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى أَبُو عُبَيْدَةَ الْحَدَّادُ عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ عَنْ أَبِي بُرْدَةَ عَنْ أَبِي مُوسَى عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِي إِسْحَاقَ ‏.‏ وَقَدْ رُوِيَ عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ عَنْ أَبِي بُرْدَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْضًا ‏.‏ وَرَوَى شُعْبَةُ وَالثَّوْرِيُّ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي بُرْدَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ ‏.‏ وَقَدْ ذَكَرَ بَعْضُ أَصْحَابِ سُفْيَانَ عَنْ سُفْيَانَ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي بُرْدَةَ عَنْ أَبِي مُوسَى ‏.‏ وَلاَ يَصِحُّ ‏.‏ وَرِوَايَةُ هَؤُلاَءِ الَّذِينَ رَوَوْا عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي بُرْدَةَ عَنْ أَبِي مُوسَى عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ ‏.‏ عِنْدِي أَصَحُّ لأَنَّ سَمَاعَهُمْ مِنْ أَبِي إِسْحَاقَ فِي أَوْقَاتٍ مُخْتَلِفَةٍ وَإِنْ كَانَ شُعْبَةُ وَالثَّوْرِيُّ أَحْفَظَ وَأَثْبَتَ مِنْ جَمِيعِ هَؤُلاَءِ الَّذِينَ رَوَوْا عَنْ أَبِي إِسْحَاقَ هَذَا الْحَدِيثَ فَإِنَّ رِوَايَةَ هَؤُلاَءِ عِنْدِي أَشْبَهُ لأَنَّ شُعْبَةَ وَالثَّوْرِيَّ سَمِعَا هَذَا الْحَدِيثَ مِنْ أَبِي إِسْحَاقَ فِي مَجْلِسٍ وَاحِدٍ ‏.‏ وَمِمَّا يَدُلُّ عَلَى ذَلِكَ مَا حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ سَمِعْتُ سُفْيَانَ الثَّوْرِيَّ، يَسْأَلُ أَبَا إِسْحَاقَ أَسَمِعْتَ أَبَا بُرْدَةَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ ‏.‏ فَقَالَ نَعَمْ ‏.‏ فَدَلَّ هَذَا الْحَدِيثُ عَلَى أَنَّ سَمَاعَ شُعْبَةَ وَالثَّوْرِيِّ هَذَا الْحَدِيثَ فِي وَقْتٍ وَاحِدٍ ‏.‏ وَإِسْرَائِيلُ هُوَ ثِقَةٌ ثَبْتٌ فِي أَبِي إِسْحَاقَ ‏.‏ سَمِعْتُ مُحَمَّدَ بْنَ الْمُثَنَّى يَقُولُ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ مَهْدِيٍّ يَقُولُ مَا فَاتَنِي مِنْ حَدِيثِ الثَّوْرِيِّ عَنْ أَبِي إِسْحَاقَ الَّذِي فَاتَنِي إِلاَّ لَمَّا اتَّكَلْتُ بِهِ عَلَى إِسْرَائِيلَ لأَنَّهُ كَانَ يَأْتِي بِهِ أَتَمَّ ‏.‏ - وَحَدِيثُ عَائِشَةَ فِي هَذَا الْبَابِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ حَدِيثٌ عِنْدِي حَسَنٌ ‏.‏ رَوَاهُ ابْنُ جُرَيْجٍ عَنْ سُلَيْمَانَ بْنِ مُوسَى عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ الْحَجَّاجُ بْنُ أَرْطَاةَ وَجَعْفَرُ بْنُ رَبِيعَةَ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلُهُ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَصْحَابِ الْحَدِيثِ فِي حَدِيثِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ ابْنُ جُرَيْجٍ ثُمَّ لَقِيتُ الزُّهْرِيَّ فَسَأَلْتُهُ فَأَنْكَرَهُ ‏.‏ فَضَعَّفُوا هَذَا الْحَدِيثَ مِنْ أَجْلِ هَذَا ‏.‏ وَذُكِرَ عَنْ يَحْيَى بْنِ مَعِينٍ أَنَّهُ قَالَ لَمْ يَذْكُرْ هَذَا الْحَرْفَ عَنِ ابْنِ جُرَيْجٍ إِلاَّ إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ ‏.‏ قَالَ يَحْيَى بْنُ مَعِينٍ وَسَمَاعُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ عَنِ ابْنِ جُرَيْجٍ لَيْسَ بِذَاكَ إِنَّمَا صَحَّحَ كُتُبَهُ عَلَى كُتُبِ عَبْدِ الْمَجِيدِ بْنِ عَبْدِ الْعَزِيزِ بْنِ أَبِي رَوَّادٍ مَا سَمِعَ مِنِ ابْنِ جُرَيْجٍ وَضَعَّفَ يَحْيَى رِوَايَةَ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ عَنِ ابْنِ جُرَيْجٍ ‏.‏ - وَالْعَمَلُ فِي هَذَا الْبَابِ عَلَى حَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ ‏.‏ عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ وَعَلِيُّ بْنُ أَبِي طَالِبٍ وَعَبْدُ اللَّهِ بْنُ عَبَّاسٍ وَأَبُو هُرَيْرَةَ وَغَيْرُهُمْ ‏.‏ وَهَكَذَا رُوِيَ عَنْ بَعْضِ فُقَهَاءِ التَّابِعِينَ أَنَّهُمْ قَالُوا لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏.‏ مِنْهُمْ سَعِيدُ بْنُ الْمُسَيَّبِ وَالْحَسَنُ الْبَصْرِيُّ وَشُرَيْحٌ وَإِبْرَاهِيمُ النَّخَعِيُّ وَعُمَرُ بْنُ عَبْدِ الْعَزِيزِ وَغَيْرُهُمْ وَبِهَذَا يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَالأَوْزَاعِيُّ وَعَبْدُ اللَّهِ بْنُ الْمُبَارَكِ وَمَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{1102}\hadithgrade{Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated that:The Messenger of Allah said: "Whichever woman married without the permission of her Wali her marriage is invalid, her marriage is invalid, her marriage is invalid. If he entered into her, then the Mahr is for her in lieu of what he enjoyed from her private part. If they disagree, then the Sultan is the Wali for one who has no Wali}}
\hadithdefcmd{tirmidhi}{1103}{حَدَّثَنَا يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَغَايَا اللاَّتِي يُنْكِحْنَ أَنْفُسَهُنَّ بِغَيْرِ بَيِّنَةٍ ‏"‏ ‏.‏ قَالَ يُوسُفُ بْنُ حَمَّادٍ رَفَعَ عَبْدُ الأَعْلَى هَذَا الْحَدِيثَ فِي التَّفْسِيرِ وَأَوْقَفَهُ فِي كِتَابِ الطَّلاَقِ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{1103}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated that :the Prophet said: "The adulteresses are the ones who marry themselves without Bayyinah (proof)}}
\hadithdefcmd{tirmidhi}{1104}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا غُنْدَرٌ، مُحَمَّدُ بْنُ جَعْفَرٍ عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، نَحْوَهُ وَلَمْ يَرْفَعْهُ ‏.‏ وَهَذَا أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَيْرُ مَحْفُوظٍ لاَ نَعْلَمُ أَحَدًا رَفَعَهُ إِلاَّ مَا رُوِيَ عَنْ عَبْدِ الأَعْلَى عَنْ سَعِيدٍ عَنْ قَتَادَةَ مَرْفُوعًا ‏.‏ وَرُوِيَ عَنْ عَبْدِ الأَعْلَى عَنْ سَعِيدٍ هَذَا الْحَدِيثُ مَوْقُوفًا وَالصَّحِيحُ مَا رُوِيَ عَنِ ابْنِ عَبَّاسٍ قَوْلُهُ لاَ نِكَاحَ إِلاَّ بِبَيِّنَةٍ هَكَذَا رَوَى أَصْحَابُ قَتَادَةَ عَنْ قَتَادَةَ عَنْ جَابِرِ بْنِ زَيْدٍ عَنِ ابْنِ عَبَّاسٍ لاَ نِكَاحَ إِلاَّ بِبَيِّنَةٍ ‏.‏ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ نَحْوَ هَذَا مَوْقُوفًا ‏.‏ وَفِي هَذَا الْبَابِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَأَنَسٍ وَأَبِي هُرَيْرَةَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ وَغَيْرِهِمْ قَالُوا لاَ نِكَاحَ إِلاَّ بِشُهُودٍ ‏.‏ لَمْ يَخْتَلِفُوا فِي ذَلِكَ مَنْ مَضَى مِنْهُمْ إِلاَّ قَوْمًا مِنَ الْمُتَأَخِّرِينَ مِنْ أَهْلِ الْعِلْمِ ‏.‏ وَإِنَّمَا اخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا إِذَا شَهِدَ وَاحِدٌ بَعْدَ وَاحِدٍ فَقَالَ أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَهْلِ الْكُوفَةِ وَغَيْرِهِمْ لاَ يَجُوزُ النِّكَاحُ حَتَّى يَشْهَدَ الشَّاهِدَانِ مَعًا عِنْدَ عُقْدَةِ النِّكَاحِ ‏.‏ وَقَدْ رَأَى بَعْضُ أَهْلِ الْمَدِينَةِ إِذَا أُشْهِدَ وَاحِدٌ بَعْدَ وَاحِدٍ فَإِنَّهُ جَائِزٌ إِذَا أَعْلَنُوا ذَلِكَ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَغَيْرِهِ ‏.‏ هَكَذَا قَالَ إِسْحَاقُ فِيمَا حَكَى عَنْ أَهْلِ الْمَدِينَةِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ يَجُوزُ شَهَادَةُ رَجُلٍ وَامْرَأَتَيْنِ فِي النِّكَاحِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1104}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{(Another chain) from Sa'eed bin Abi Arubah, with similar (narration), :And he did not narrate it in Marfu form, and this is more correct}}
\hadithdefcmd{tirmidhi}{1105}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْثَرُ بْنُ الْقَاسِمِ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ عَلَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم التَّشَهُّدَ فِي الصَّلاَةِ وَالتَّشَهُّدَ فِي الْحَاجَةِ قَالَ ‏"‏ التَّشَهُّدُ فِي الصَّلاَةِ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏ وَالتَّشَهُّدُ فِي الْحَاجَةِ ‏"‏ إِنَّ الْحَمْدَ لِلَّهِ نَسْتَعِينُهُ وَنَسْتَغْفِرُهُ وَنَعُوذُ بِاللَّهِ مِنْ شُرُورِ أَنْفُسِنَا وَسَيِّئَاتِ أَعْمَالِنَا فَمَنْ يَهْدِهِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلْ فَلاَ هَادِيَ لَهُ وَأَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏ وَيَقْرَأُ ثَلاَثَ آيَاتٍ ‏.‏ قَالَ عَبْثَرٌ فَفَسَّرَهُ لَنَا سُفْيَانُ الثَّوْرِيُّ ‏:‏ ‏(‏اتَّقوا الله حقَّ تقاتهِ ولا تموتنَّ إلاَّ وأنتمْ مسلمونَ‏)‏‏.‏ ‏(‏اتّقوا الله الَّذي تساءلونَ بهِ والأرحامَ إنَّ اللهَ كانَ عليكُم رقيباً‏)‏‏.‏ ‏(‏اتَّقوا الله وقولوا قولاً سديداً‏)‏‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَدِيِّ بْنِ حَاتِمٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ حَدِيثٌ حَسَنٌ رَوَاهُ الأَعْمَشُ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي الأَحْوَصِ عَنْ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ شُعْبَةُ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي عُبَيْدَةَ عَنْ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَكِلاَ الْحَدِيثَيْنِ صَحِيحٌ لأَنَّ إِسْرَائِيلَ جَمَعَهُمَا فَقَالَ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي الأَحْوَصِ وَأَبِي عُبَيْدَةَ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَدْ قَالَ بَعْضُ أَهْلِ الْعِلْمِ إِنَّ النِّكَاحَ جَائِزٌ بِغَيْرِ خُطْبَةٍ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَغَيْرِهِ مِنْ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1105}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud narrated:"The Messenger of Allah taught us the Tashah-hud for Salat and the Tashah-hud for Al-Hajjah." He said: "The Tashah-hud for Salat is: (At-Tahiyyatulilah, was-walawtu wat-tayyibatu. As-Salamu alaika ayyuhan-Nabiyyu wa rahmatullilahi wa barakatuhu, As-Salamu alina wa ala ibadillahis-salihin. Ashahadu an la ilaha illallah, wa ashhadu anna Muhammadan abduha wa Raduluh.) 'All greetings, prayers, and pure words are for Allah. Peace be upon you O Prophet, and Allah's mercy and His blessings. Peace be upon us and all of the righteous worshippers of Allah. I testify that none has the right to be worshiped but Allah. and I testify that Muhammad is His slave and His Messenger."And the Tashah-hud for Al-Hajjah is: 'Indeed all praise is due to Allah, we seek His aid, and we seek His forgiveness, and we seek refuge with Allah from the evils of our souls and the mischief of our deeds. (Innal-Hamdlillahi nasta'inuhu, wa nastaghfirhu, wa na'udhu billahi min sharuri anfusina, wa sayy'ita a'malina, man yahdihi, sala mudilla lahu, wa manyudlil, fala Hadiya lahu, wa ashadu an la ilaha illallah wa ashadu anna Muhammadan abduhu wa Rasuluh) 'Whoever He guides - meaning Allah - then here is none to lead him astray, and whomever He misleads, then there is no guide for him. I testify that none has the right to be worshipped but Allah, and I testify that Muhammad is His worshipper and Messenger.'" He said: "And he recited three Ayat}}
\hadithdefcmd{tirmidhi}{1106}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ خُطْبَةٍ لَيْسَ فِيهَا تَشَهُّدٌ فَهِيَ كَالْيَدِ الْجَذْمَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ [صَحِيحٌ] غَرِيبٌ ‏.‏\hadithno{1106}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "Every Khutbah that does not have the Tashah-hud in it, then it is like a severed hand}}
\hadithdefcmd{tirmidhi}{1107}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُنْكَحُ الثَّيِّبُ حَتَّى تُسْتَأْمَرَ وَلاَ تُنْكَحُ الْبِكْرُ حَتَّى تُسْتَأْذَنَ وَإِذْنُهَا الصُّمُوتُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَابْنِ عَبَّاسٍ وَعَائِشَةَ وَالْعُرْسِ بْنِ عَمِيرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الثَّيِّبَ لاَ تُزَوَّجُ حَتَّى تُسْتَأْمَرَ وَإِنْ زَوَّجَهَا الأَبُ مِنْ غَيْرِ أَنْ يَسْتَأْمِرَهَا فَكَرِهَتْ ذَلِكَ فَالنِّكَاحُ مَفْسُوخٌ عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي تَزْوِيجِ الأَبْكَارِ إِذَا زَوَّجَهُنَّ الآبَاءُ فَرَأَى أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَهْلِ الْكُوفَةِ وَغَيْرِهِمْ أَنَّ الأَبَ إِذَا زَوَّجَ الْبِكْرَ وَهِيَ بَالِغَةٌ بِغَيْرِ أَمْرِهَا فَلَمْ تَرْضَ بِتَزْوِيجِ الأَبِ فَالنِّكَاحُ مَفْسُوخٌ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْمَدِينَةِ تَزْوِيجُ الأَبِ عَلَى الْبِكْرِ جَائِزٌ وَإِنْ كَرِهَتْ ذَلِكَ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1107}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:The Prophet said: "A matron should not be given in marriage until she is consulted, and a virgin should not be given in marriage until her permission is sought, and her silence is her permission}}
\hadithdefcmd{tirmidhi}{1108}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الأَيِّمُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْبِكْرُ تُسْتَأْذَنُ فِي نَفْسِهَا وَإِذْنُهَا صُمَاتُهَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى شُعْبَةُ وَسُفْيَانُ الثَّوْرِيُّ هَذَا الْحَدِيثَ عَنْ مَالِكِ بْنِ أَنَسٍ ‏.‏ وَقَدِ احْتَجَّ بَعْضُ النَّاسِ فِي إِجَازَةِ النِّكَاحِ بِغَيْرِ وَلِيٍّ بِهَذَا الْحَدِيثِ وَلَيْسَ فِي هَذَا الْحَدِيثِ مَا احْتَجُّوا بِهِ لأَنَّهُ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ وَهَكَذَا أَفْتَى بِهِ ابْنُ عَبَّاسٍ بَعْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏.‏ وَإِنَّمَا مَعْنَى قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ الأَيِّمُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا ‏"‏ ‏.‏ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ أَنَّ الْوَلِيَّ لاَ يُزَوِّجُهَا إِلاَّ بِرِضَاهَا وَأَمْرِهَا فَإِنْ زَوَّجَهَا فَالنِّكَاحُ مَفْسُوخٌ عَلَى حَدِيثِ خَنْسَاءَ بِنْتِ خِذَامٍ حَيْثُ زَوَّجَهَا أَبُوهَا وَهِيَ ثَيِّبٌ فَكَرِهَتْ ذَلِكَ فَرَدَّ النَّبِيُّ صلى الله عليه وسلم نِكَاحَهُ ‏.‏\hadithno{1108}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Abbas narrated that:The Messenger of Allah said: "The matron has more right to herself than her Wali, and the virgin is to give permission for herself, and her silence is her permission}}
\hadithdefcmd{tirmidhi}{1109}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْيَتِيمَةُ تُسْتَأْمَرُ فِي نَفْسِهَا فَإِنْ صَمَتَتْ فَهُوَ إِذْنُهَا وَإِنْ أَبَتْ فَلاَ جَوَازَ عَلَيْهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي مُوسَى وَابْنِ عُمَرَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي تَزْوِيجِ الْيَتِيمَةِ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ أَنَّ الْيَتِيمَةَ إِذَا زُوِّجَتْ فَالنِّكَاحُ مَوْقُوفٌ حَتَّى تَبْلُغَ فَإِذَا بَلَغَتْ فَلَهَا الْخِيَارُ فِي إِجَازَةِ النِّكَاحِ أَوْ فَسْخِهِ ‏.‏ وَهُوَ قَوْلُ بَعْضِ التَّابِعِينَ وَغَيْرِهِمْ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ يَجُوزُ نِكَاحُ الْيَتِيمَةِ حَتَّى تَبْلُغَ ‏.‏ وَلاَ يَجُوزُ الْخِيَارُ فِي النِّكَاحِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَغَيْرِهِمَا مِنْ أَهْلِ الْعِلْمِ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ إِذَا بَلَغَتِ الْيَتِيمَةُ تِسْعَ سِنِينَ فَزُوِّجَتْ فَرَضِيَتْ فَالنِّكَاحُ جَائِزٌ وَلاَ خِيَارَ لَهَا إِذَا أَدْرَكَتْ ‏.‏ وَاحْتَجَّا بِحَدِيثِ عَائِشَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَنَى بِهَا وَهِيَ بِنْتُ تِسْعِ سِنِينَ ‏.‏ وَقَدْ قَالَتْ عَائِشَةُ إِذَا بَلَغَتِ الْجَارِيَةُ تِسْعَ سِنِينَ فَهِيَ امْرَأَةٌ ‏.‏\hadithno{1109}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "An orphan is to be consulted about herself, then if she is silent that is her permission, and if she refuses, then do not authorize it (the marriage) for her" (meaning: when she attains the age of puberty and refuses it)}}
\hadithdefcmd{tirmidhi}{1110}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرَأَةٍ زَوَّجَهَا وَلِيَّانِ فَهِيَ لِلأَوَّلِ مِنْهُمَا وَمَنْ بَاعَ بَيْعًا مِنْ رَجُلَيْنِ فَهُوَ لِلأَوَّلِ مِنْهُمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ نَعْلَمُ بَيْنَهُمْ فِي ذَلِكَ اخْتِلاَفًا إِذَا زَوَّجَ أَحَدُ الْوَلِيَّيْنِ قَبْلَ الآخَرِ فَنِكَاحُ الأَوَّلِ جَائِزٌ وَنِكَاحُ الآخَرِ مَفْسُوخٌ وَإِذَا زَوَّجَا جَمِيعًا فَنِكَاحُهُمَا جَمِيعًا مَفْسُوخٌ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1110}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Samurah bin Jundab narrated that:The Messenger of Allah said: "Whichever woman is given in marriage by two Wali, then her case is in accordance with the first of them, and whoever sells something to two men, then it is for the first of them}}
\hadithdefcmd{tirmidhi}{1111}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ زُهَيْرِ بْنِ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا عَبْدٍ تَزَوَّجَ بِغَيْرِ إِذْنِ سَيِّدِهِ فَهُوَ عَاهِرٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَلاَ يَصِحُّ وَالصَّحِيحُ عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ عَنْ جَابِرٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ نِكَاحَ الْعَبْدِ بِغَيْرِ إِذْنِ سَيِّدِهِ لاَ يَجُوزُ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ وَغَيْرِهِمَا ‏بِلَا اخْتِلَافٍ\hadithno{1111}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin Abdullah narrated that:The Prophet said: "Whichever slave gets married without the permission of his owner, then he is a fornicator}}
\hadithdefcmd{tirmidhi}{1112}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا عَبْدٍ تَزَوَّجَ بِغَيْرِ إِذْنِ سَيِّدِهِ فَهُوَ عَاهِرٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1112}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{(Another chain) Jabir bin Abdullah narrated that:Abdullah narrated that the Prophet said: "Whichever slave gets married without the permission of his owner, then he is a fornicator}}
\hadithdefcmd{tirmidhi}{1113}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، قَالُوا حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، أَنَّ امْرَأَةً، مِنْ بَنِي فَزَارَةَ تَزَوَّجَتْ عَلَى نَعْلَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرَضِيتِ مِنْ نَفْسِكِ وَمَالِكِ بِنَعْلَيْنِ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ فَأَجَازَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَأَبِي هُرَيْرَةَ وَسَهْلِ بْنِ سَعْدٍ وَأَبِي سَعِيدٍ وَأَنَسٍ وَعَائِشَةَ وَجَابِرٍ وَأَبِي حَدْرَدٍ الأَسْلَمِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَامِرِ بْنِ رَبِيعَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْمَهْرِ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ الْمَهْرُ عَلَى مَا تَرَاضَوْا عَلَيْهِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ مَالِكُ بْنُ أَنَسٍ لاَ يَكُونُ الْمَهْرُ أَقَلَّ مِنْ رُبْعِ دِينَارٍ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْكُوفَةِ لاَ يَكُونُ الْمَهْرُ أَقَلَّ مِنْ عَشْرَةِ دَرَاهِمَ ‏.‏\hadithno{1113}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Amr bin Rabi'ah narrated from his father:"A woman from Banu Fazarah was married for (the dowry of) two sandals. So the Messenger of Allah said to her: 'Do you approve of (exchanging) yourself and your wealth for two sandals?' She said: 'Yes.'" He said: "So he permitted it}}
\hadithdefcmd{tirmidhi}{1114}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا إِسْحَاقُ بْنُ عِيسَى، وَعَبْدُ اللَّهِ بْنُ نَافِعٍ الصَّائِغُ، قَالاَ أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَتْهُ امْرَأَةٌ فَقَالَتْ إِنِّي وَهَبْتُ نَفْسِي لَكَ ‏.‏ فَقَامَتْ طَوِيلاً فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ فَزَوِّجْنِيهَا إِنْ لَمْ تَكُنْ لَكَ بِهَا حَاجَةٌ ‏.‏ فَقَالَ ‏"‏ هَلْ عِنْدَكَ مِنْ شَيْءٍ تُصْدِقُهَا ‏"‏ ‏.‏ فَقَالَ مَا عِنْدِي إِلاَّ إِزَارِي هَذَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِزَارَكَ إِنْ أَعْطَيْتَهَا جَلَسْتَ وَلاَ إِزَارَ لَكَ فَالْتَمِسْ شَيْئًا ‏"‏ قَالَ مَا أَجِدُ ‏.‏ قَالَ ‏"‏ فَالْتَمِسْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏ ‏.‏ قَالَ فَالْتَمَسَ فَلَمْ يَجِدْ شَيْئًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ مَعَكَ مِنَ الْقُرْآنِ شَيْءٌ ‏"‏ ‏.‏ قَالَ نَعَمْ سُورَةُ كَذَا وَسُورَةُ كَذَا ‏.‏ لِسُوَرٍ سَمَّاهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ زَوَّجْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ الشَّافِعِيُّ إِلَى هَذَا الْحَدِيثِ فَقَالَ إِنْ لَمْ يَكُنْ لَهُ شَيْءٌ يُصْدِقُهَا وَتَزَوَّجَهَا عَلَى سُورَةٍ مِنَ الْقُرْآنِ فَالنِّكَاحُ جَائِزٌ وَيُعَلِّمُهَا سُورَةً مِنَ الْقُرْآنِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ النِّكَاحُ جَائِزٌ وَيَجْعَلُ لَهَا صَدَاقَ مِثْلِهَا ‏.‏ وَهُوَ قَوْلُ أَهْلِ الْكُوفَةِ وَأَحْمَدَ وَإِسْحَاقَ\hadithno{1114}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl bin Sa'd As-Sa'idi narrated that:A woman came to the Messenger of Allah and said: "I present myself to you (for marriage)." So she stood for a long time. Then a man said: "O Messenger of Allah! Marry her to me if you have no need of her." So he said: "Do you have anything to give her as a dowry?" He said: "I have nothing except this Izar." So the Messenger of Allah said: "If you give her your Izar then you will have no Izar, so search for something." He said: "I did not find anything." He said: "Search for something, even if it just an iron ring." He said: So he searched but he did not find anything. The Messenger of Allah said: "Do you have any Qur'an (memorized)?" He said: "Yes. This Surat and that Surat." And he named the Surat. So the Messenger of Allah said: "I marry her to you for what you have (memorized) of the Qur'an}}
\hadithdefcmd{tirmidhi}{1114p2}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي الْعَجْفَاءِ السُّلَمِيِّ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ أَلاَ لاَ تُغَالُوا صَدُقَةَ النِّسَاءِ فَإِنَّهَا لَوْ كَانَتْ مَكْرُمَةً فِي الدُّنْيَا أَوْ تَقْوَى عِنْدَ اللَّهِ لَكَانَ أَوْلاَكُمْ بِهَا نَبِيُّ اللَّهِ صلى الله عليه وسلم مَا عَلِمْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم نَكَحَ شَيْئًا مِنْ نِسَائِهِ وَلاَ أَنْكَحَ شَيْئًا مِنْ بَنَاتِهِ عَلَى أَكْثَرَ مِنْ ثِنْتَىْ عَشْرَةَ أُوقِيَّةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الْعَجْفَاءِ السُّلَمِيُّ اسْمُهُ هَرَمٌ ‏.‏ وَالأُوقِيَّةُ عِنْدَ أَهْلِ الْعِلْمِ أَرْبَعُونَ دِرْهَمًا وَثِنْتَا عَشْرَةَ أُوقِيَّةً أَرْبَعُمِائَةٍ وَثَمَانُونَ دِرْهَمًا ‏.‏\hadithno{1114.2}\hadithtrans{Abu Al-Ajfa (As-Salami) said:"Umar bin Al-Khattab said: 'Do not exaggerate in the dowries of women. If doing so was honorable in the world or Taqwa before Allah then Allah's Prophet would have been the first of you to do it. I do not know of the Messenger of Allah marrying any of his women, nor giving any of his daughters in marriage, for more than twelve Uqiyah}}
\hadithdefcmd{tirmidhi}{1115}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، وَعَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْتَقَ صَفِيَّةَ وَجَعَلَ عِتْقَهَا صَدَاقَهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ صَفِيَّةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَكَرِهَ بَعْضُ أَهْلِ الْعِلْمِ أَنْ يُجْعَلَ عِتْقُهَا صَدَاقَهَا حَتَّى يَجْعَلَ لَهَا مَهْرًا سِوَى الْعِتْقِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1115}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:"The Messenger of Allah emancipated Safiyyah and he made her emancipation her dowry}}
\hadithdefcmd{tirmidhi}{1116}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الْفَضْلِ بْنِ يَزِيدَ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ يُؤْتَوْنَ أَجْرَهُمْ مَرَّتَيْنِ عَبْدٌ أَدَّى حَقَّ اللَّهِ وَحَقَّ مَوَالِيهِ فَذَلِكَ يُؤْتَى أَجْرَهُ مَرَّتَيْنِ وَرَجُلٌ كَانَتْ عِنْدَهُ جَارِيَةٌ وَضِيئَةٌ فَأَدَّبَهَا فَأَحْسَنَ أَدَبَهَا ثُمَّ أَعْتَقَهَا ثُمَّ تَزَوَّجَهَا يَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ فَذَلِكَ يُؤْتَى أَجْرَهُ مَرَّتَيْنِ وَرَجُلٌ آمَنَ بِالْكِتَابِ الأَوَّلِ ثُمَّ جَاءَ الْكِتَابُ الآخَرُ فَآمَنَ بِهِ فَذَلِكَ يُؤْتَى أَجْرَهُ مَرَّتَيْنِ ‏"‏ ‏.‏ حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ صَالِحِ بْنِ صَالِحٍ، وَهُوَ ابْنُ حَىٍّ عَنِ الشَّعْبِيِّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي مُوسَى حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو بُرْدَةَ بْنُ أَبِي مُوسَى اسْمُهُ عَامِرُ بْنُ عَبْدِ اللَّهِ بْنِ قَيْسٍ ‏.‏ وَرَوَى شُعْبَةُ وَسُفْيَانُ الثَّوْرِيُّ هَذَا الْحَدِيثَ عَنْ صَالِحِ بْنِ صَالِحِ بْنِ حَىٍّ ‏.‏ وَصَالِحُ بْنُ صَالِحِ بْنِ حَىٍّ هُوَ وَالِدُ الْحَسَنِ بْنِ صَالِحِ بْنِ حَىٍّ ‏.‏\hadithno{1116}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Burdah bin Abi Musa narrated from his father that the Messenger of Allah said:"Three will receive their reward twice: A slave who fulfills the rights of Allah and the rights of his owners, then he will be given his reward twice. And a man who has a beautiful slave girl, so he teaches her good manners, then he frees her, then he married her seeking the Face of Allah by that; then he will be given his reward twice. And a man who believed in an earlier Book, then another Book came to him and he believed in it; then he will be given his reward twice}}
\hadithdefcmd{tirmidhi}{1117}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ أَيُّمَا رَجُلٍ نَكَحَ امْرَأَةً فَدَخَلَ بِهَا فَلاَ يَحِلُّ لَهُ نِكَاحُ ابْنَتِهَا فَإِنْ لَمْ يَكُنْ دَخَلَ بِهَا فَلْيَنْكِحِ ابْنَتَهَا وَأَيُّمَا رَجُلٍ نَكَحَ امْرَأَةً فَدَخَلَ بِهَا أَوْ لَمْ يَدْخُلْ بِهَا فَلاَ يَحِلُّ لَهُ نِكَاحُ أُمِّهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ يَصِحُّ مِنْ قِبَلِ إِسْنَادِهِ وَإِنَّمَا رَوَاهُ ابْنُ لَهِيعَةَ وَالْمُثَنَّى بْنُ الصَّبَّاحِ عَنْ عَمْرِو بْنِ شُعَيْبٍ ‏.‏ وَالْمُثَنَّى بْنُ الصَّبَّاحِ وَابْنُ لَهِيعَةَ يُضَعَّفَانِ فِي الْحَدِيثِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ قَالُوا إِذَا تَزَوَّجَ الرَّجُلُ امْرَأَةً ثُمَّ طَلَّقَهَا قَبْلَ أَنْ يَدْخُلَ بِهَا حَلَّ لَهُ أَنْ يَنْكِحَ ابْنَتَهَا وَإِذَا تَزَوَّجَ الرَّجُلُ الاِبْنَةَ فَطَلَّقَهَا قَبْلَ أَنْ يَدْخُلَ بِهَا لَمْ يَحِلَّ لَهُ نِكَاحُ أُمِّهَا لِقَوْلِ اللَّهِ تَعَالَى ‏(‏وَأُمَّهَاتُ نِسَائِكُمْ ‏)‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1117}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather that:The Prophet said: "Whichever man married a woman and entered into her, then it is not lawful for him to marry her daughter. If he did not enter into her then he may marry her daughter. And whichever man married a woman and he entered into her, or he did not enter into her, then it is not lawful for him to marry her mother}}
\hadithdefcmd{tirmidhi}{1118}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتِ امْرَأَةُ رِفَاعَةَ الْقُرَظِيِّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي كُنْتُ عِنْدَ رِفَاعَةَ فَطَلَّقَنِي فَبَتَّ طَلاَقِي فَتَزَوَّجْتُ عَبْدَ الرَّحْمَنِ بْنَ الزُّبَيْرِ وَمَا مَعَهُ إِلاَّ مِثْلُ هُدْبَةِ الثَّوْبِ ‏.‏ فَقَالَ ‏ "‏ أَتُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ لاَ حَتَّى تَذُوقِي عُسَيْلَتَهُ وَيَذُوقَ عُسَيْلَتَكِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَنَسٍ وَالرُّمَيْصَاءِ أَوِ الْغُمَيْصَاءِ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الرَّجُلَ إِذَا طَلَّقَ امْرَأَتَهُ ثَلاَثًا فَتَزَوَّجَتْ زَوْجًا غَيْرَهُ فَطَلَّقَهَا قَبْلَ أَنْ يَدْخُلَ بِهَا أَنَّهَا لاَ تَحِلُّ لِلزَّوْجِ الأَوَّلِ إِذَا لَمْ يَكُنْ جَامَعَ الزَّوْجُ الآخَرُ ‏.‏\hadithno{1118}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"The wife of Rifa'ah Al-Qurzi came to the Messenger of Allah and said: 'I was with Rifa'ah and he divorced me irrevocably. Then I married Abdur-Rahman bin Az-Zubair, but he only has the likes of the fringe of a garment.' So he said: 'Perhaps you want me to return to Rifa'ah? No, not until you taste his sweetness, and he tastes your sweetness}}
\hadithdefcmd{tirmidhi}{1119}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَشْعَثُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ زُبَيْدٍ الأَيَامِيُّ، حَدَّثَنَا مُجَالِدٌ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، وَعَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالاَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ الْمُحِلَّ وَالْمُحَلَّلَ لَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابِنْ مَسْعُودٍ وَأَبِي هُرَيْرَةَ وَعُقْبَةَ بْنِ عَامِرٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ وَجَابِرٍ حَدِيثٌ مَعْلُولٌ ‏.‏ هَكَذَا رَوَى أَشْعَثُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ مُجَالِدٍ عَنْ عَامِرٍ هُوَ الشَّعْبِيُّ عَنِ الْحَارِثِ عَنْ عَلِيٍّ وَعَامِرٌ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَهَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِالْقَائِمِ لأَنَّ مُجَالِدَ بْنَ سَعِيدٍ قَدْ ضَعَّفَهُ بَعْضُ أَهْلِ الْعِلْمِ مِنْهُمْ أَحْمَدُ بْنُ حَنْبَلٍ ‏.‏ وَرَوَى عَبْدُ اللَّهِ بْنُ نُمَيْرٍ هَذَا الْحَدِيثَ عَنْ مُجَالِدٍ عَنْ عَامِرٍ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ عَنْ عَلِيٍّ ‏.‏ وَهَذَا قَدْ وَهِمَ فِيهِ ابْنُ نُمَيْرٍ وَالْحَدِيثُ الأَوَّلُ أَصَحُّ ‏.‏ وَقَدْ رَوَاهُ مُغِيرَةُ وَابْنُ أَبِي خَالِدٍ وَغَيْرُ وَاحِدٍ عَنِ الشَّعْبِيِّ عَنِ الْحَارِثِ عَنْ عَلِيٍّ ‏.‏\hadithno{1119}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin Abdullah and Ali narrated:"The Messenger of Allah cursed the Muhill and the one the Muhallal was done for}}
\hadithdefcmd{tirmidhi}{1120}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي قَيْسٍ، عَنْ هُزَيْلِ بْنِ شُرَحْبِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُحِلَّ وَالْمُحَلَّلَ لَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو قَيْسٍ الأَوْدِيُّ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ ثَرْوَانَ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ وَعُثْمَانُ بْنُ عَفَّانَ وَعَبْدُ اللَّهِ بْنُ عُمَرَ وَغَيْرُهُمْ وَهُوَ قَوْلُ الْفُقَهَاءِ مِنَ التَّابِعِينَ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ قَالَ وَسَمِعْتُ الْجَارُودَ بْنَ مُعَاذٍ يَذْكُرُ عَنْ وَكِيعٍ أَنَّهُ قَالَ بِهَذَا وَقَالَ يَنْبَغِي أَنْ يُرْمَى بِهَذَا الْبَابِ مِنْ قَوْلِ أَصْحَابِ الرَّأْىِ ‏.‏ قَالَ جَارُودٌ قَالَ وَكِيعٌ وَقَالَ سُفْيَانُ إِذَا تَزَوَّجَ الرَّجُلُ الْمَرْأَةَ لِيُحَلِّلَهَا ثُمَّ بَدَا لَهُ أَنْ يُمْسِكَهَا فَلاَ يَحِلُّ لَهُ أَنْ يُمْسِكَهَا حَتَّى يَتَزَوَّجَهَا بِنِكَاحٍ جَدِيدٍ ‏.‏\hadithno{1120}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Mas'ud narrated:"The Messenger of Allah cursed the Muhill and the one the Muhallal was done for}}
\hadithdefcmd{tirmidhi}{1121}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ، وَالْحَسَنِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِمَا، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ مُتْعَةِ النِّسَاءِ وَعَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ زَمَنَ خَيْبَرَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَبْرَةَ الْجُهَنِيِّ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَإِنَّمَا رُوِيَ عَنِ ابْنِ عَبَّاسٍ شَيْءٌ مِنَ الرُّخْصَةِ فِي الْمُتْعَةِ ثُمَّ رَجَعَ عَنْ قَوْلِهِ حَيْثُ أُخْبِرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَأَمْرُ أَكْثَرِ أَهْلِ الْعِلْمِ عَلَى تَحْرِيمِ الْمُتْعَةِ وَهُوَ قَوْلُ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1121}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ali bin Abi Talib narrated:"The Prophet prohibited the Mut'ah with women, and the meat of domestic donkeys during (the campaign of) Khaibar}}
\hadithdefcmd{tirmidhi}{1122}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا سُفْيَانُ بْنُ عُقْبَةَ، أَخُو قَبِيصَةَ بْنِ عُقْبَةَ حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّمَا كَانَتِ الْمُتْعَةُ فِي أَوَّلِ الإِسْلاَمِ كَانَ الرَّجُلُ يَقْدَمُ الْبَلْدَةَ لَيْسَ لَهُ بِهَا مَعْرِفَةٌ فَيَتَزَوَّجُ الْمَرْأَةَ بِقَدْرِ مَا يَرَى أَنَّهُ يُقِيمُ فَتَحْفَظُ لَهُ مَتَاعَهُ وَتُصْلِحُ لَهُ شَيْئَهُ حَتَّى إِذَا نَزَلَتِ الآيَةُ ‏:‏ ‏(‏ إِلاَّ عَلَى أَزْوَاجِهِمْ أَوْ مَا مَلَكَتْ أَيْمَانُهُمْ ‏)‏ قَالَ ابْنُ عَبَّاسٍ فَكُلُّ فَرْجٍ سِوَى هَذَيْنِ فَهُوَ حَرَامٌ ‏.‏\hadithno{1122}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Muhammad bin Ka'b narrated that:Ibn Abbas said: "Mut'ah was only during the beginning of Islam. A man would arrive in a land that he was not familiar with so he would marry a woman for the extent of time that he thought he would remain there. So his Mut'ah was upheld and his case was fine until the (following) Ayah was revealed: Except their wives or what their right hands possess. Then every private part other than those became unlawful}}
\hadithdefcmd{tirmidhi}{1123}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا حُمَيْدٌ، وَهُوَ الطَّوِيلُ قَالَ حَدَّثَ الْحَسَنُ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ جَلَبَ وَلاَ جَنَبَ وَلاَ شِغَارَ فِي الإِسْلاَمِ وَمَنِ انْتَهَبَ نُهْبَةً فَلَيْسَ مِنَّا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَأَبِي رَيْحَانَةَ وَابْنِ عُمَرَ وَجَابِرٍ وَمُعَاوِيَةَ وَأَبِي هُرَيْرَةَ وَوَائِلِ بْنِ حُجْرٍ ‏.‏\hadithno{1123}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Imran bin Husain narrated that :The Prophet said: "There is no Jalab, no Janab, and no Shighar in Islam. And whoever takes some property by force, then he is not from us}}
\hadithdefcmd{tirmidhi}{1124}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الشِّغَارِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ نِكَاحَ الشِّغَارِ ‏.‏ وَالشِّغَارُ أَنْ يُزَوِّجَ الرَّجُلُ ابْنَتَهُ عَلَى أَنْ يُزَوِّجَهُ الآخَرُ ابْنَتَهُ أَوْ أُخْتَهُ وَلاَ صَدَاقَ بَيْنَهُمَا ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ نِكَاحُ الشِّغَارِ مَفْسُوخٌ وَلاَ يَحِلُّ وَإِنْ جُعِلَ لَهُمَا صَدَاقًا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَرُوِيَ عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ أَنَّهُ قَالَ يُقَرَّانِ عَلَى نِكَاحِهِمَا وَيُجْعَلُ لَهُمَا صَدَاقُ الْمِثْلِ ‏.‏ وَهُوَ قَوْلُ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{1124}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"The Prophet prohibited Shighar}}
\hadithdefcmd{tirmidhi}{1125}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ أَبِي حَرِيزٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ تُزَوَّجَ الْمَرْأَةُ عَلَى عَمَّتِهَا أَوْ عَلَى خَالَتِهَا ‏.‏ وَأَبُو حَرِيزٍ اسْمُهُ عَبْدُ اللَّهِ بْنُ حُسَيْنٍ ‏.‏ حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي سَعِيدٍ وَأَبِي أُمَامَةَ وَجَابِرٍ وَعَائِشَةَ وَأَبِي مُوسَى وَسَمُرَةَ بْنِ جُنْدَبٍ ‏.‏\hadithno{1125}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"The Prophet prohibited marrying a woman along with her paternal aunt or along with her maternal aunt}}
\hadithdefcmd{tirmidhi}{1126}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، حَدَّثَنَا عَامِرٌ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا أَوِ الْعَمَّةُ عَلَى ابْنَةِ أَخِيهَا أَوِ الْمَرْأَةُ عَلَى خَالَتِهَا أَوِ الْخَالَةُ عَلَى بِنْتِ أُخْتِهَا لاَ تُنْكَحُ الصُّغْرَى عَلَى الْكُبْرَى وَلاَ الْكُبْرَى عَلَى الصُّغْرَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ لاَ نَعْلَمُ بَيْنَهُمُ اخْتِلاَفًا أَنَّهُ لاَ يَحِلُّ لِلرَّجُلِ أَنْ يَجْمَعَ بَيْنَ الْمَرْأَةِ وَعَمَّتِهَا أَوْ خَالَتِهَا فَإِنْ نَكَحَ امْرَأَةً عَلَى عَمَّتِهَا أَوْ خَالَتِهَا أَوِ الْعَمَّةَ عَلَى بِنْتِ أَخِيهَا فَنِكَاحُ الأُخْرَى مِنْهُمَا مَفْسُوخٌ ‏.‏ وَبِهِ يَقُولُ عَامَّةُ أَهْلِ الْعِلْمِ ‏.‏ قَالَ أَبُو عِيسَى أَدْرَكَ الشَّعْبِيُّ أَبَا هُرَيْرَةَ وَرَوَى عَنْهُ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا فَقَالَ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى الشَّعْبِيُّ عَنْ رَجُلٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{1126}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah prohibited that a woman be married along with her paternal aunt, or the paternal aunt along with her brother's daughter, or a woman with her maternal aunt, or the maternal aunt along with her sister's daughter, and the younger is not to be married with the older, nor the older with the younger}}
\hadithdefcmd{tirmidhi}{1127}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدِ بْنِ عَبْدِ اللَّهِ الْيَزَنِيِّ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحَقَّ الشُّرُوطِ أَنْ يُوفَى بِهَا مَا اسْتَحْلَلْتُمْ بِهِ الْفُرُوجَ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ قَالَ إِذَا تَزَوَّجَ رَجُلٌ امْرَأَةً وَشَرَطَ لَهَا أَنْ لاَ يُخْرِجَهَا مِنْ مِصْرِهَا فَلَيْسَ لَهُ أَنْ يُخْرِجَهَا ‏.‏ وَهُوَ قَوْلُ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَرُوِيَ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ أَنَّهُ قَالَ شَرْطُ اللَّهِ قَبْلَ شَرْطِهَا ‏.‏ كَأَنَّهُ رَأَى لِلزَّوْجِ أَنْ يُخْرِجَهَا وَإِنْ كَانَتِ اشْتَرَطَتْ عَلَى زَوْجِهَا أَنْ لاَ يُخْرِجَهَا ‏.‏ وَذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَبَعْضِ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{1127}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Uqbah bin Amir Al-Juhani narrated that:The Messenger of Allah said: "Indeed the conditions most deserving to be fulfilled are those that make the private parts lawful among you}}
\hadithdefcmd{tirmidhi}{1128}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، أَنَّ غَيْلاَنَ بْنَ سَلَمَةَ الثَّقَفِيَّ، أَسْلَمَ وَلَهُ عَشْرُ نِسْوَةٍ فِي الْجَاهِلِيَّةِ فَأَسْلَمْنَ مَعَهُ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَتَخَيَّرَ أَرْبَعًا مِنْهُنَّ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَاهُ مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ هَذَا حَدِيثٌ غَيْرُ مَحْفُوظٍ وَالصَّحِيحُ مَا رَوَى شُعَيْبُ بْنُ أَبِي حَمْزَةَ وَغَيْرُهُ عَنِ الزُّهْرِيِّ قَالَ حُدِّثْتُ عَنْ مُحَمَّدِ بْنِ سُوَيْدٍ الثَّقَفِيِّ أَنَّ غَيْلاَنَ بْنَ سَلَمَةَ أَسْلَمَ وَعِنْدَهُ عَشْرُ نِسْوَةٍ ‏.‏ قَالَ مُحَمَّدٌ وَإِنَّمَا حَدِيثُ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ أَنَّ رَجُلاً مِنْ ثَقِيفٍ طَلَّقَ نِسَاءَهُ فَقَالَ لَهُ عُمَرُ لَتُرَاجِعَنَّ نِسَاءَكَ أَوْ لأَرْجُمَنَّ قَبْرَكَ كَمَا رُجِمَ قَبْرُ أَبِي رِغَالٍ ‏.‏ قَالَ أَبُو عِيسَى وَالْعَمَلُ عَلَى حَدِيثِ غَيْلاَنَ بْنِ سَلَمَةَ عِنْدَ أَصْحَابِنَا مِنْهُمُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{1128}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Umar narrated:"Ghilan bin Salamah Ath-Thaqafi accepted Islam and he had ten wives in Jahiliyyah who accepted Islam along with him. So the Prophet ordered (him) to chose four (of them)}}
\hadithdefcmd{tirmidhi}{1129}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي وَهْبٍ الْجَيْشَانِيِّ، أَنَّهُ سَمِعَ ابْنَ فَيْرُوزَ الدَّيْلَمِيَّ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَسْلَمْتُ وَتَحْتِي أُخْتَانِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اخْتَرْ أَيَّتَهُمَا شِئْتَ ‏"‏ ‏.‏\hadithno{1129}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Wahb Al-Jaishani narrated that:He heard Ibn Fairuz Ad-Dhailami narrating from his father: "I went to the Prophet and said: 'O Messenger of Allah! I accepted Islam and I had two sisters (as wives).' So the Messenger of Allah said: 'Chose whichever of them you will}}
\hadithdefcmd{tirmidhi}{1130}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ يَحْيَى بْنَ أَيُّوبَ، يُحَدِّثُ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي وَهْبٍ الْجَيْشَانِيِّ، عَنِ الضَّحَّاكِ بْنِ فَيْرُوزَ الدَّيْلَمِيِّ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَسْلَمْتُ وَتَحْتِي أُخْتَانِ ‏.‏ قَالَ ‏ "‏ اخْتَرْ أَيَّتَهُمَا شِئْتَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو وَهْبٍ الْجَيْشَانِيُّ اسْمُهُ الدَّيْلَمُ بْنُ هُوشَعَ ‏.‏\hadithno{1130}\hadithgrade{Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Wahb Al-Jaishani narrated from Ad-Dhahhak bin Fairuz Ad-Dailami from his father:"I said: 'O Messenger of Allah! I accepted Islam and I had two sisters (as wives).' So Messenger of Allah said: 'Chose whichever of them you will}}
\hadithdefcmd{tirmidhi}{1131}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ الشَّيْبَانِيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ رَبِيعَةَ بْنِ سُلَيْمٍ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ رُوَيْفِعِ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يَسْقِ مَاءَهُ وَلَدَ غَيْرِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ رُوَيْفِعِ بْنِ ثَابِتٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ لِلرَّجُلِ إِذَا اشْتَرَى جَارِيَةً وَهِيَ حَامِلٌ أَنْ يَطَأَهَا حَتَّى تَضَعَ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي الدَّرْدَاءِ وَابْنِ عَبَّاسٍ وَالْعِرْبَاضِ بْنِ سَارِيَةَ وَأَبِي سَعِيدٍ ‏.‏\hadithno{1131}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ruwaifi bin Thabit narrated that :the Prophet said: "Whoever believes in Allah and the Last Day, then he does not levy his water on someone else's child}}
\hadithdefcmd{tirmidhi}{1132}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا عُثْمَانُ الْبَتِّيُّ، عَنْ أَبِي الْخَلِيلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَصَبْنَا سَبَايَا يَوْمَ أَوْطَاسٍ وَلَهُنَّ أَزْوَاجٌ فِي قَوْمِهِنَّ فَذَكَرُوا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَنَزَلَتْ ‏:‏ ‏(‏وَالْمُحْصَنَاتُ مِنَ النِّسَاءِ إِلاَّ مَا مَلَكَتْ أَيْمَانُكُمْ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَهَكَذَا رَوَاهُ الثَّوْرِيُّ عَنْ عُثْمَانَ الْبَتِّيِّ عَنْ أَبِي الْخَلِيلِ عَنْ أَبِي سَعِيدٍ ‏.‏ وَأَبُو الْخَلِيلِ اسْمُهُ صَالِحُ بْنُ أَبِي مَرْيَمَ ‏.‏ وَرَوَى هَمَّامٌ، هَذَا الْحَدِيثَ عَنْ قَتَادَةَ، عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ أَبِي عَلْقَمَةَ الْهَاشِمِيِّ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا بِذَلِكَ عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا هَمَّامٌ، ‏.‏\hadithno{1132}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated:"We got some captives on the day of Awtas, and they had husbands among their peopled. They mentioned that to the Messenger of Allah, so the following was revealed: And women who are already married, except those whom your right hands posses}}
\hadithdefcmd{tirmidhi}{1133}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ رَافِعِ بْنِ خَدِيجٍ وَأَبِي جُحَيْفَةَ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1133}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Mas'ud Al-Ansari narrated:"The Messenger of Allah prohibited the price of a dog, the dowry of a fornicator, and the payment made to the fortune-teller}}
\hadithdefcmd{tirmidhi}{1134}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قُتَيْبَةُ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم وَقَالَ أَحْمَدُ - قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَبِيعُ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ وَلاَ يَخْطُبُ عَلَى خِطْبَةِ أَخِيهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَمُرَةَ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ مَالِكُ بْنُ أَنَسٍ إِنَّمَا مَعْنَى كَرَاهِيَةِ أَنْ يَخْطُبَ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ إِذَا خَطَبَ الرَّجُلُ الْمَرْأَةَ فَرَضِيَتْ بِهِ فَلَيْسَ لأَحَدٍ أَنْ يَخْطُبَ عَلَى خِطْبَتِهِ ‏.‏ وَقَالَ الشَّافِعِيُّ مَعْنَى هَذَا الْحَدِيثِ ‏"‏ لاَ يَخْطُبُ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ ‏"‏ ‏.‏ هَذَا عِنْدَنَا إِذَا خَطَبَ الرَّجُلُ الْمَرْأَةَ فَرَضِيَتْ بِهِ وَرَكَنَتْ إِلَيْهِ فَلَيْسَ لأَحَدٍ أَنْ يَخْطُبَ عَلَى خِطْبَتِهِ فَأَمَّا قَبْلَ أَنْ يَعْلَمَ رِضَاهَا أَوْ رُكُونَهَا إِلَيْهِ فَلاَ بَأْسَ أَنْ يَخْطُبَهَا وَالْحُجَّةُ فِي ذَلِكَ حَدِيثُ فَاطِمَةَ بِنْتِ قَيْسٍ حَيْثُ جَاءَتِ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَتْ لَهُ أَنَّ أَبَا جَهْمِ بْنَ حُذَيْفَةَ وَمُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ خَطَبَاهَا فَقَالَ ‏"‏ أَمَّا أَبُو جَهْمٍ فَرَجُلٌ لاَ يَرْفَعُ عَصَاهُ عَنِ النِّسَاءِ وَأَمَّا مُعَاوِيَةُ فَصُعْلُوكٌ لاَ مَالَ لَهُ وَلَكِنِ انْكِحِي أُسَامَةَ ‏"‏ ‏.‏ فَمَعْنَى هَذَا الْحَدِيثِ عِنْدَنَا وَاللَّهُ أَعْلَمُ أَنَّ فَاطِمَةَ لَمْ تُخْبِرْهُ بِرِضَاهَا بِوَاحِدٍ مِنْهُمَا وَلَوْ أَخْبَرَتْهُ لَمْ يُشِرْ عَلَيْهَا بِغَيْرِ الَّذِي ذَكَرَتْ ‏.‏\hadithno{1134}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "A man is not to sell over his brother's sale, nor is he to propose to whom his brother has proposed}}
\hadithdefcmd{tirmidhi}{1135}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ أَبِي الْجَهْمِ، قَالَ دَخَلْتُ أَنَا وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ فَحَدَّثَتْنَا أَنَّ زَوْجَهَا طَلَّقَهَا ثَلاَثًا وَلَمْ يَجْعَلْ لَهَا سُكْنَى وَلاَ نَفَقَةً ‏.‏ قَالَتْ وَوَضَعَ لِي عَشَرَةَ أَقْفِزَةٍ عِنْدَ ابْنِ عَمٍّ لَهُ خَمْسَةً شَعِيرًا وَخَمْسَةً بُرًّا ‏.‏ قَالَتْ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ ‏.‏ قَالَتْ فَقَالَ ‏"‏ صَدَقَ ‏"‏ ‏.‏ قَالَتْ فَأَمَرَنِي أَنْ أَعْتَدَّ فِي بَيْتِ أُمِّ شَرِيكٍ ثُمَّ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ بَيْتَ أُمِّ شَرِيكٍ بَيْتٌ يَغْشَاهُ الْمُهَاجِرُونَ وَلَكِنِ اعْتَدِّي فِي بَيْتِ ابْنِ أُمِّ مَكْتُومٍ فَعَسَى أَنْ تُلْقِي ثِيَابَكِ فَلاَ يَرَاكِ فَإِذَا انْقَضَتْ عِدَّتُكِ فَجَاءَ أَحَدٌ يَخْطُبُكِ فَآذِنِينِي ‏"‏ ‏.‏ فَلَمَّا انْقَضَتْ عِدَّتِي خَطَبَنِي أَبُو جَهْمٍ وَمُعَاوِيَةُ ‏.‏ قَالَتْ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏"‏ أَمَّا مُعَاوِيَةُ فَرَجُلٌ لاَ مَالَ لَهُ وَأَمَّا أَبُو جَهْمٍ فَرَجُلٌ شَدِيدٌ عَلَى النِّسَاءِ ‏"‏ ‏.‏ قَالَتْ فَخَطَبَنِي أُسَامَةُ بْنُ زَيْدٍ فَتَزَوَّجَنِي فَبَارَكَ اللَّهُ لِي فِي أُسَامَةَ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ سُفْيَانُ الثَّوْرِيُّ عَنْ أَبِي بَكْرِ بْنِ أَبِي الْجَهْمِ، نَحْوَ هَذَا الْحَدِيثِ وَزَادَ فِيهِ فَقَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ انْكِحِي أُسَامَةَ ‏"‏ ‏.‏ حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ حَدَّثَنَا وَكِيعٌ عَنْ سُفْيَانَ عَنْ أَبِي بَكْرِ بْنِ أَبِي الْجَهْمِ بِهَذَا ‏.‏\hadithno{1135}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Bakr bin Al-Jahm narrated:"Abu Salamah bin Abdur-Rahman and I visited Fatimah bint Qais. She narrated to us that her husband had divorced her three times, and he did not leave her with anywhere to live nor any wealth. She said: 'He left ten Aqfizah for me with the son of his uncle: five were of barley, five of wheat.' She said: 'I went to the Messenger of Allah and mentioned that to him.' She said: 'He said: 'He is correct.'" (She said: ) 'So he ordered me to complete my Iddah in the home of Umm Sharik. But then the Messenger of Allah said to me: "Umm Sharik's home is visited by Muhajirun, so spend your Iddah in the home of Ibn Umm Maktum, for there you can remove your garments and he will not see you. Then when your Iddah is completed and someone proposed to you come to me." 'So when my Iddah completed. Abu Jahm and Mu'awiyah proposed to me.' She said: 'I went to the Messenger of Allah and mentioned that to him, and he said: "As for Mu'awiyah, he is a man with no wealth, and as for Abu Jahm he is a man who is harsh with women." She said: 'Then Usamah bin Zaid proposed to me, and he married me. So Allah blessed me with Usamah}}
\hadithdefcmd{tirmidhi}{1136}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ جَابِرٍ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نَعْزِلُ فَزَعَمَتِ الْيَهُودُ أَنَّهَا الْمَوْءُودَةُ الصُّغْرَى ‏.‏ فَقَالَ ‏ "‏ كَذَبَتِ الْيَهُودُ إِنَّ اللَّهَ إِذَا أَرَادَ أَنْ يَخْلُقَهُ لَمْ يَمْنَعْهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَالْبَرَاءِ وَأَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ ‏.‏\hadithno{1136}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated:"We said: 'O Messenger of Allah! We practice Azl, but the Jews claim that it is minor infanticide.' So he said: 'The Jews lie. When Allah wants to create it, nothing can prevent Him}}
\hadithdefcmd{tirmidhi}{1137}{حَدَّثَنَا قُتَيْبَةُ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا نَعْزِلُ وَالْقُرْآنُ يَنْزِلُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي الْعَزْلِ ‏.‏ وَقَالَ مَالِكُ بْنُ أَنَسٍ تُسْتَأْمَرُ الْحُرَّةُ فِي الْعَزْلِ وَلاَ تُسْتَأْمَرُ الأَمَةُ ‏.‏\hadithno{1137}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir bin Abdullah narrated:"We practiced Azl while the Qur'an was being revealed}}
\hadithdefcmd{tirmidhi}{1138}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ قَزَعَةَ، هُوَ ابْنُ يَحْيَى عَنْ أَبِي سَعِيدٍ، قَالَ ذُكِرَ الْعَزْلُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ لِمَ يَفْعَلُ ذَلِكَ أَحَدُكُمْ ‏"‏ ‏.‏ زَادَ ابْنُ أَبِي عُمَرَ فِي حَدِيثِهِ وَلَمْ يَقُلْ لاَ يَفْعَلْ ذَاكَ أَحَدُكُمْ ‏.‏ قَالاَ فِي حَدِيثِهِمَا ‏"‏ فَإِنَّهَا لَيْسَتْ نَفْسٌ مَخْلُوقَةٌ إِلاَّ اللَّهُ خَالِقُهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي سَعِيدٍ ‏.‏ وَقَدْ كَرِهَ الْعَزْلَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏\hadithno{1138}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Sa'eed narrated:"Azl was mentined before the Messenger of Allah and he said: 'Why would one of you do that?}}
\hadithdefcmd{tirmidhi}{1139}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَوْ شِئْتُ أَنْ أَقُولَ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَكِنَّهُ قَالَ السُّنَّةُ إِذَا تَزَوَّجَ الرَّجُلُ الْبِكْرَ عَلَى امْرَأَتِهِ أَقَامَ عِنْدَهَا سَبْعًا وَإِذَا تَزَوَّجَ الثَّيِّبَ عَلَى امْرَأَتِهِ أَقَامَ عِنْدَهَا ثَلاَثًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَفَعَهُ مُحَمَّدُ بْنُ إِسْحَاقَ عَنْ أَيُّوبَ عَنْ أَبِي قِلاَبَةَ عَنْ أَنَسٍ وَلَمْ يَرْفَعْهُ بَعْضُهُمْ ‏.‏ قَالَ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ قَالُوا إِذَا تَزَوَّجَ الرَّجُلُ امْرَأَةً بِكْرًا عَلَى امْرَأَتِهِ أَقَامَ عِنْدَهَا سَبْعًا ثُمَّ قَسَمَ بَيْنَهُمَا بَعْدُ بِالْعَدْلِ وَإِذَا تَزَوَّجَ الثَّيِّبَ عَلَى امْرَأَتِهِ أَقَامَ عِنْدَهَا ثَلاَثًا ‏.‏ وَهُوَ قَوْلُ مَالِكٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ إِذَا تَزَوَّجَ الْبِكْرَ عَلَى امْرَأَتِهِ أَقَامَ عِنْدَهَا ثَلاَثًا وَإِذَا تَزَوَّجَ الثَّيِّبَ أَقَامَ عِنْدَهَا لَيْلَتَيْنِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1139}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Qilabah narrated from Anas bin Malik, :He (Abu Qilabah) said: "If I wish, I could say: 'The Messenger of Allah said'" but he said: "The Sunnah when a man married a virgin after he already has a wife, is that he stays with her seven (nights). And when he married a matron when he already has a wife, he stays with her three (nights)}}
\hadithdefcmd{tirmidhi}{1140}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْسِمُ بَيْنَ نِسَائِهِ فَيَعْدِلُ وَيَقُولُ ‏"‏ اللَّهُمَّ هَذِهِ قِسْمَتِي فِيمَا أَمْلِكُ فَلاَ تَلُمْنِي فِيمَا تَمْلِكُ وَلاَ أَمْلِكُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ هَكَذَا رَوَاهُ غَيْرُ وَاحِدٍ عَنْ حَمَّادِ بْنِ سَلَمَةَ عَنْ أَيُّوبَ عَنْ أَبِي قِلاَبَةَ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ عَنْ عَائِشَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْسِمُ ‏.‏ وَرَوَاهُ حَمَّادُ بْنُ زَيْدٍ وَغَيْرُ وَاحِدٍ عَنْ أَيُّوبَ عَنْ أَبِي قِلاَبَةَ مُرْسَلاً أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْسِمُ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ لاَ تَلُمْنِي فِيمَا تَمْلِكُ وَلاَ أَمْلِكُ ‏"‏ ‏.‏ إِنَّمَا يَعْنِي بِهِ الْحُبَّ وَالْمَوَدَّةَ كَذَا فَسَّرَهُ بَعْضُ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1140}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated that:The Prophet would divide (his time) equally between his wives and said: "O Allah! This is my division in what I have control over, so do not punish me for what You have control over which I do not have control over}}
\hadithdefcmd{tirmidhi}{1141}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ عِنْدَ الرَّجُلِ امْرَأَتَانِ فَلَمْ يَعْدِلْ بَيْنَهُمَا جَاءَ يَوْمَ الْقِيَامَةِ وَشِقُّهُ سَاقِطٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَإِنَّمَا أَسْنَدَ هَذَا الْحَدِيثَ هَمَّامُ بْنُ يَحْيَى عَنْ قَتَادَةَ ‏.‏ وَرَوَاهُ هِشَامٌ الدَّسْتَوَائِيُّ عَنْ قَتَادَةَ قَالَ كَانَ يُقَالُ ‏.‏ وَلاَ نَعْرِفُ هَذَا الْحَدِيثَ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ هَمَّامٍ ‏وَهَمَّامٌ ثِقَةٌ حَافِظٌ\hadithno{1141}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "When a man has two wives and he is not just between them, he will come on the Day of Judgment with one side drooping}}
\hadithdefcmd{tirmidhi}{1142}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الْحَجَّاجِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَدَّ ابْنَتَهُ زَيْنَبَ عَلَى أَبِي الْعَاصِي بْنِ الرَّبِيعِ بِمَهْرٍ جَدِيدٍ وَنِكَاحٍ جَدِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ فِي إِسْنَادِهِ مَقَالٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الْمَرْأَةَ إِذَا أَسْلَمَتْ قَبْلَ زَوْجِهَا ثُمَّ أَسْلَمَ زَوْجُهَا وَهِيَ فِي الْعِدَّةِ أَنَّ زَوْجَهَا أَحَقُّ بِهَا مَا كَانَتْ فِي الْعِدَّةِ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالأَوْزَاعِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1142}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather:"The Messenger of Allah returned his daughter Zainab to Abul-As bin Ar-Rabi with a new dowry and a new wedding}}
\hadithdefcmd{tirmidhi}{1143}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي دَاوُدُ بْنُ الْحُصَيْنِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَدَّ النَّبِيُّ صلى الله عليه وسلم ابْنَتَهُ زَيْنَبَ عَلَى أَبِي الْعَاصِي بْنِ الرَّبِيعِ بَعْدَ سِتِّ سِنِينَ بِالنِّكَاحِ الأَوَّلِ وَلَمْ يُحْدِثْ نِكَاحًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ بِإِسْنَادِهِ بَأْسٌ وَلَكِنْ لاَ نَعْرِفُ وَجْهَ هَذَا الْحَدِيثِ وَلَعَلَّهُ قَدْ جَاءَ هَذَا مِنْ قِبَلِ دَاوُدَ بْنِ حُصَيْنٍ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{1143}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet returned his daughter Zainab to Abul-As bin Ar-Rabi after six years in the first marriage without renewing the marriage}}
\hadithdefcmd{tirmidhi}{1144}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، جَاءَ مُسْلِمًا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ جَاءَتِ امْرَأَتُهُ مُسْلِمَةً فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهَا كَانَتْ أَسْلَمَتْ مَعِي فَرُدَّهَا عَلَىَّ ‏.‏ فَرَدَّهَا عَلَيْهِ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ سَمِعْتُ عَبْدَ بْنَ حُمَيْدٍ، يَقُولُ سَمِعْتُ يَزِيدَ بْنَ هَارُونَ، يَذْكُرُ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، هَذَا الْحَدِيثَ وَحَدِيثَ الْحَجَّاجِ عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَدَّ ابْنَتَهُ زَيْنَبَ عَلَى أَبِي الْعَاصِي بِمَهْرٍ جَدِيدٍ وَنِكَاحٍ جَدِيدٍ ‏.‏ قَالَ يَزِيدُ بْنُ هَارُونَ حَدِيثُ ابْنِ عَبَّاسٍ أَجْوَدُ إِسْنَادًا ‏.‏ وَالْعَمَلُ عَلَى حَدِيثِ عَمْرِو بْنِ شُعَيْبٍ ‏.‏\hadithno{1144}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"A man became a Muslim during the time of the Prophet, then his wife became a Muslim, so he said: 'O Messenger of Allah! She accepted Islam along with me, so return her to me.' So he returned her to him}}
\hadithdefcmd{tirmidhi}{1145}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنِ ابْنِ مَسْعُودٍ، أَنَّهُ سُئِلَ عَنْ رَجُلٍ، تَزَوَّجَ امْرَأَةً وَلَمْ يَفْرِضْ لَهَا صَدَاقًا وَلَمْ يَدْخُلْ بِهَا حَتَّى مَاتَ ‏.‏ فَقَالَ ابْنُ مَسْعُودٍ لَهَا مِثْلُ صَدَاقِ نِسَائِهَا لاَ وَكْسَ وَلاَ شَطَطَ وَعَلَيْهَا الْعِدَّةُ وَلَهَا الْمِيرَاثُ ‏.‏ فَقَامَ مَعْقِلُ بْنُ سِنَانٍ الأَشْجَعِيُّ فَقَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بِرْوَعَ بِنْتِ وَاشِقٍ امْرَأَةٍ مِنَّا مِثْلَ الَّذِي قَضَيْتَ ‏.‏ فَفَرِحَ بِهَا ابْنُ مَسْعُودٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ الْجَرَّاحِ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، وَعَبْدُ الرَّزَّاقِ، كِلاَهُمَا عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْهُ، مِنْ غَيْرِ وَجْهٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَبِهِ يَقُولُ الثَّوْرِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عَلِيُّ بْنُ أَبِي طَالِبٍ وَزَيْدُ بْنُ ثَابِتٍ وَابْنُ عَبَّاسٍ وَابْنُ عُمَرَ إِذَا تَزَوَّجَ الرَّجُلُ الْمَرْأَةَ وَلَمْ يَدْخُلْ بِهَا وَلَمْ يَفْرِضْ لَهَا صَدَاقًا حَتَّى مَاتَ قَالُوا لَهَا الْمِيرَاثُ وَلاَ صَدَاقَ لَهَا وَعَلَيْهَا الْعِدَّةُ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ قَالَ لَوْ ثَبَتَ حَدِيثُ بِرْوَعَ بِنْتِ وَاشِقٍ لَكَانَتِ الْحُجَّةُ فِيمَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنِ الشَّافِعِيِّ أَنَّهُ رَجَعَ بِمِصْرَ بَعْدُ عَنْ هَذَا الْقَوْلِ وَقَالَ بِحَدِيثِ بِرْوَعَ بِنْتِ وَاشِقٍ ‏.‏\hadithno{1145}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Alqamah narrated that :Ibn Mas'ud was asked about a man who married a woman and he did not stipulate the dowry for her, and he did not enter into her until he died. So Ibn Mas'ud said: "She gets the same dowry as other women, no less and no more, she has to observe the Iddah, and she gets inheritance." So Ma'qil bin Sinan Al-Ashja'I stood and said: "The Messenger of Allah judged the same as you have judged regarding Birwa bint Washiq, a woman of ours." So Ibn Mas'ud was happy about that}}
